@@ -1,7 +1,7 @@
 #
 # This file is part of MooseX-Types-ElasticSearch
 #
-# This software is Copyright (c) 2012 by Moritz Onken.
+# This software is Copyright (c) 2013 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package MooseX::Types::ElasticSearch;
 {
-  $MooseX::Types::ElasticSearch::VERSION = '0.0.2';
+  $MooseX::Types::ElasticSearch::VERSION = '0.0.3';
 }
 
 # ABSTRACT: Useful types for ElasticSearch
@@ -53,7 +53,7 @@ coerce ES, from ArrayRef, via {
                           timeout   => 30, );
 };
 
-enum QueryType, qw(query_and_fetch query_then_fetch dfs_query_and_fetch dfs_query_then_fetch scan count);
+enum QueryType, [qw(query_and_fetch query_then_fetch dfs_query_and_fetch dfs_query_then_fetch scan count)];
 
 class_type ESDateTime;
 coerce ESDateTime, from Str, via {
@@ -75,17 +75,19 @@ coerce Location, from Str, via { [ reverse split(/,/) ] };
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Types::ElasticSearch - Useful types for ElasticSearch
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -125,11 +127,10 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Moritz Onken.
+This software is Copyright (c) 2013 by Moritz Onken.
 
 This is free software, licensed under:
 
   The (three-clause) BSD License
 
 =cut
-
